FCCDropdownList<T> class

Inheritance

Constructors

FCCDropdownList({Key? key, String? labelText, T? value, List<DropdownMenuItem<T>>? items, ValueChanged<T?>? onChanged, FormFieldValidator<T>? validator, bool readOnly = false, Color? fillColor, double? fontSize, FontWeight? fontWeight, String? fontFamily, Color? textColor, TextStyle? style, TextAlign? textAlign, String? helperText, String? hintText, bool required = false, String? requiredMessage, bool use3DEffect = true, bool isPill = false, bool enableFocusEffect = true, String? tooltip, String? semanticLabel, bool isSearchable = false, String? searchPlaceholder, Duration searchDebounce = const Duration(milliseconds: 250), Future<List<DropdownMenuItem<T>>> asyncItemsFetcher(String query)?, String searchTextResolver(T value)?, bool showClearButton = false, List<FCCDropdownGroup<T>>? groups, Widget itemBuilder(BuildContext context, T value, bool isSelected)?, bool pinSelectedOnTop = false, bool autoFlipDropdown = true, double maxDropdownHeight = 260.0})
const

Properties

asyncItemsFetcher Future<List<DropdownMenuItem<T>>> Function(String query)?
final
autoFlipDropdown bool
final
enableFocusEffect bool
final
fillColor Color?
final
fontFamily String?
final
fontSize double?
final
fontWeight FontWeight?
final
groups List<FCCDropdownGroup<T>>?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
hintText String?
final
isPill bool
final
isSearchable bool
final
itemBuilder Widget Function(BuildContext context, T value, bool isSelected)?
final
items List<DropdownMenuItem<T>>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String?
final
maxDropdownHeight double
final
onChanged ValueChanged<T?>?
final
pinSelectedOnTop bool
final
readOnly bool
final
required bool
Required flag
final
requiredMessage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchDebounce Duration
final
searchPlaceholder String?
final
searchTextResolver String Function(T value)?
Used for text-based filtering when not using asyncItemsFetcher. If null, we try to infer from Text child.
final
semanticLabel String?
final
showClearButton bool
final
style TextStyle?
final
textAlign TextAlign?
final
textColor Color?
final
tooltip String?
final
use3DEffect bool
final
validator FormFieldValidator<T>?
final
value → T?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FCCDropdownList<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited