FCCExpandableSection class

Inheritance

Constructors

FCCExpandableSection({Key? key, required String title, required bool expanded, required VoidCallback onHeaderTap, required Widget child, Widget? customTitle, IconData expandIcon = Icons.expand_more, double expandedTurns = 0.5, Duration duration = const Duration(milliseconds: 300), EdgeInsets padding = EdgeInsets.zero, EdgeInsets titlePadding = EdgeInsets.zero, Color? titleColor, TextStyle? titleTextStyle, Curve animationCurve = Curves.linear, Widget? leadingIcon, List<BoxShadow>? boxShadow, double borderRadius = 12.0, bool showDivider = false, ThemeData? theme, Color? backgroundColor, VoidCallback? onExpand, VoidCallback? onCollapse, bool scrollOnExpand = false, ScrollController? scrollController, double scrollOffset = -40.0, bool isNeumorphic = true, NeumorphicStyle neumorphicStyle = NeumorphicStyle.lowered, double neumorphicBorderRadius = 24.0, EdgeInsets neumorphicPadding = const EdgeInsets.fromLTRB(10, 5, 10, 5), Color? neumorphicBaseColor, double? neumorphicHeight, double neumorphicIntensity = 0.35})
const

Properties

animationCurve Curve
final
backgroundColor Color?
Card / container background color (non-neumorphic).
final
borderRadius double
final
boxShadow List<BoxShadow>?
final
child Widget
final
customTitle Widget?
final
duration Duration
final
expanded bool
final
expandedTurns double
final
expandIcon IconData
final
hashCode int
The hash code for this object.
no setterinherited
isNeumorphic bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingIcon Widget?
final
neumorphicBaseColor Color?
final
neumorphicBorderRadius double
final
neumorphicHeight double?
final
neumorphicIntensity double
final
neumorphicPadding EdgeInsets
final
neumorphicStyle NeumorphicStyle
final
onCollapse VoidCallback?
final
onExpand VoidCallback?
final
onHeaderTap VoidCallback
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
scrollOffset double
final
scrollOnExpand bool
final
showDivider bool
final
theme ThemeData?
Optional theme override
final
title String
final
titleColor Color?
final
titlePadding EdgeInsets
final
titleTextStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FCCExpandableSection>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited