FCCFloatingActionItem class

Single speed-dial action.

Constructors

FCCFloatingActionItem({required IconData icon, required VoidCallback onTap, Color? backgroundColor, Color? iconColor, String? label})
const

Properties

backgroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
iconColor Color?
final
label String?
final
onTap VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited