FCCFloatingButton class

Inheritance

Constructors

FCCFloatingButton({Key? key, required VoidCallback onPressed, required IconData icon, Color? backgroundColor, String? caption, bool draggable = true, Offset? initialPosition, dynamic onPositionChanged(Offset)?, String? tooltip, double elevation = 6.0, Color? shadowColor, ShapeBorder? shape, Color? iconColor, double? iconSize, double borderRadius = 16.0, bool savePosition = true, String? semanticLabel, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, VoidCallback? onLongPress, Size? minSize, Size? maxSize, bool animateMovement = true, String? heroTag})
const

Properties

animateMovement bool
final
backgroundColor Color?
final
borderRadius double
final
caption String?
final
draggable bool
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
heroTag String?
final
icon IconData
final
iconColor Color?
final
iconSize double?
final
initialPosition Offset?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
final
maxSize Size?
final
minSize Size?
final
onLongPress VoidCallback?
final
onPositionChanged → dynamic Function(Offset)?
final
onPressed VoidCallback
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePosition bool
final
semanticLabel String?
final
shadowColor Color?
final
shape ShapeBorder?
final
tooltip String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() FCCFloatingButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited