FCCNeumorphicCard class

Inheritance

Constructors

FCCNeumorphicCard({Key? key, required Widget child, ThemeData? theme, NeumorphicStyle style = NeumorphicStyle.lowered, EdgeInsets padding = const EdgeInsets.fromLTRB(10, 0, 10, 0), EdgeInsets innerPadding = const EdgeInsets.all(12), double? height, Color? baseColorOverride, double borderRadiusValue = 24, bool transparentBackground = true, double? borderWidth, Color? borderColor, double innerBorderWidth = 0, Color? innerBorderColor, double innerBorderInset = 10, double protrusionIntensity = 0.35})
const

Properties

baseColorOverride Color?
final
borderColor Color?
final
borderRadiusValue double
final
borderWidth double?
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
innerBorderColor Color?
final
innerBorderInset double
final
innerBorderWidth double
final
innerPadding EdgeInsets
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsets
final
protrusionIntensity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style NeumorphicStyle
final
theme ThemeData?
final
transparentBackground bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited