FCCLayoutInfo class
Constructors
- FCCLayoutInfo({required Size size, required EdgeInsets padding, required FCCDeviceType deviceType, required Orientation orientation, FCCResponsiveBreakpoints breakpoints = const FCCResponsiveBreakpoints()})
-
const
Properties
- breakpoints → FCCResponsiveBreakpoints
-
final
- contentWidth → double
-
no setter
- deviceType → FCCDeviceType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
no setter
- isDesktop → bool
-
no setter
- isLandscape → bool
-
no setter
- isMobile → bool
-
no setter
- isPortrait → bool
-
no setter
- isTablet → bool
-
no setter
- orientation → Orientation
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
- width → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited