FCCEmptyState class

Generic empty state widget with optional pull-to-refresh and neumorphic styling plus optional Lottie illustration.

Inheritance

Constructors

FCCEmptyState({Key? key, required String message, required String subMessage, Future<void> onRefresh()?, bool isNeumorphic = false, bool enableAnimation = true, NeumorphicStyle neumorphicStyle = NeumorphicStyle.lowered, EdgeInsets cardPadding = const EdgeInsets.all(24), double borderRadiusValue = 24, int animationIndex = 0, Duration animationBaseDuration = const Duration(milliseconds: 500), bool fullPage = false, String? lottieAsset, String? lottieNetwork, double lottieSize = 120})
const

Properties

animationBaseDuration Duration
final
animationIndex int
final
borderRadiusValue double
final
cardPadding EdgeInsets
final
enableAnimation bool
final
fullPage bool
final
hashCode int
The hash code for this object.
no setterinherited
isNeumorphic bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lottieAsset String?
Optional Lottie illustration for empty state.
final
lottieNetwork String?
final
lottieSize double
final
message String
final
neumorphicStyle NeumorphicStyle
final
onRefresh Future<void> Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subMessage String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited