autoDismissAfter property
How long to keep the success, error, or empty state visible before auto-dismiss. If null → no auto-dismiss.
Implementation
final Duration? autoDismissAfter;
How long to keep the success, error, or empty state visible before auto-dismiss. If null → no auto-dismiss.
final Duration? autoDismissAfter;