future property
Automatic state transition: when future is passed and initialState is FCCStateVisualType.loading, the widget listens to the future and transitions to success or error accordingly.
Implementation
final Future<void>? future;
Automatic state transition: when future is passed and initialState is FCCStateVisualType.loading, the widget listens to the future and transitions to success or error accordingly.
final Future<void>? future;