fcc_widget_library library

Classes

AnimatedProfileAvatar
FCCAnimatedEntry
FCCAnimatedNeumorphicCard
FCCAppBar
FCCClockCard
FCCCollapsingAppBar
Optional helper to create a collapsing sliver app bar using FCCAppBar
FCCDropdownGroup<T>
Optional grouping model: use this for section headers.
FCCDropdownList<T>
FCCElevatedButton
FCCEmptyState
Generic empty state widget with optional pull-to-refresh and neumorphic styling plus optional Lottie illustration.
FCCErrorState
Generic error state widget with optional retry button, neumorphic styling, Lottie support and theme-aware color scheme.
FCCExpandableSection
FCCFloatingActionItem
Single speed-dial action.
FCCFloatingBackButton
FCCFloatingButton
FCCFloatingButtonState
FCCInfoRow
FCCLayoutInfo
FCCLoadingState
============================================================================ BASIC STATE WIDGETS (backwards compatible)
FCCNeumorphicCard
FccPageHeader
FCCResponsive
Wrap a subtree to provide layout info.
FCCResponsiveBreakpoints
FCCResponsiveBuilder
One-off builder if you don't want to wrap the whole app.
FCCSectionTitle
FCCStateWidget
FCCTextField
FccValidationStyle
ProfileAvatar

Enums

AvatarAnimationMode
FCCAppBarSurfaceStyle
Surface styling for the AppBar background.
FccAutoCapitalizeMode
FCCButtonSize
FCCButtonVariant
FCCClockDesignStyle
FCCDeviceType
Device categories based on logical width
FCCFloatingButtonVisualStyle
Visual style of the floating button.
FCCHapticFeedbackMode
FCCHapticStrength
Haptic strength presets.
FCCInfoRowLayout
FCCInfoRowShape
FccInputMaskType
FccLeadingShape
FCCSnapAxis
Axis preference for edge snapping.
FCCStateVisualType
============================================================================ UNIFIED STATE WIDGET WITH DECLARATIVE API + AUTO TRANSITIONS
FccValidationSeverity
NeumorphicStyle

Functions

fCCNeumorphicDecoration({required ThemeData theme, required Color baseColor, double borderRadiusValue = 24, NeumorphicStyle style = NeumorphicStyle.lowered, bool transparentBackground = false, double? borderWidth, Color? borderColor, double protrusionIntensity = 1.0}) → BoxDecoration

Typedefs

FCCResponsiveWidgetBuilder = Widget Function(BuildContext context, FCCLayoutInfo layout)