AnimatedProfileAvatar class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedProfileAvatar
Constructors
- AnimatedProfileAvatar({Key? key, required double size, required Color borderColor, double borderWidth = 2.0, String? profileImagePath, String? userName, String? status, String? userRole, dynamic onTap(BuildContext)?, VoidCallback? onLogout, Widget profileMenuBuilder(BuildContext)?, AvatarAnimationMode animationMode = AvatarAnimationMode.fadeIn, String? heroTag, bool isLoading = false, VoidCallback? onStatusTap, Widget customFallbackAvatar(BuildContext, String initial)?, void onImageError(Object error)?, required String profileMenuTitle, required String viewProfileLabel, required String logoutLabel, required String cancelLabel})
-
const
Properties
- animationMode → AvatarAnimationMode
-
final
- borderColor → Color
-
final
- borderWidth → double
-
final
- cancelLabel → String
-
final
- customFallbackAvatar → Widget Function(BuildContext, String initial)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heroTag → String?
-
final
- isLoading → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- logoutLabel → String
-
final
- onImageError → void Function(Object error)?
-
final
- onLogout → VoidCallback?
-
final
- onStatusTap → VoidCallback?
-
final
- onTap → dynamic Function(BuildContext)?
-
final
- profileImagePath → String?
-
final
- profileMenuBuilder → Widget Function(BuildContext)?
-
final
- profileMenuTitle → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- status → String?
-
final
- userName → String?
-
final
- userRole → String?
-
final
- viewProfileLabel → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AnimatedProfileAvatar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited