FCCFloatingBackButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FCCFloatingBackButton
Constructors
- FCCFloatingBackButton({Key? key, bool enableSwipeGesture = true, bool morphToCloseWhenRoot = true, bool disableWhenNoBack = true, VoidCallback? onRootPressed, String? tooltip, String? semanticLabel, double iconSize = 24, double swipeVelocityThreshold = 300.0, Color? backgroundColor, String? caption, bool draggable = true, Offset? initialPosition, dynamic onPositionChanged(Offset)?, double elevation = 6.0, Color? shadowColor, ShapeBorder? shape, Color? iconColor, double? buttonIconSize, double borderRadius = 16.0, bool savePosition = true, double topBlockedExtent = 120.0, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, VoidCallback? onLongPress, Size? minSize, Size? maxSize, bool animateMovement = true, String? heroTag})
-
const
Properties
- animateMovement → bool
-
final
- backgroundColor → Color?
-
final
- borderRadius → double
-
final
-
final
- caption → String?
-
final
- disableWhenNoBack → bool
-
final
- draggable → bool
-
final
- elevation → double
-
final
- enableSwipeGesture → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heroTag → String?
-
final
- iconColor → Color?
-
final
- iconSize → double
-
final
- initialPosition → Offset?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry?
-
final
- maxSize → Size?
-
final
- minSize → Size?
-
final
- morphToCloseWhenRoot → bool
-
final
- onLongPress → VoidCallback?
-
final
- onPositionChanged → dynamic Function(Offset)?
-
final
- onRootPressed → VoidCallback?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savePosition → bool
-
final
- semanticLabel → String?
-
final
- shadowColor → Color?
-
final
- shape → ShapeBorder?
-
final
- swipeVelocityThreshold → double
-
Swipe gesture config
final
- tooltip → String?
-
final
- topBlockedExtent → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited