FCCInfoRow class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FCCInfoRow
Constructors
-
FCCInfoRow({Key? key, required String label, String? value, IconData? leadingIcon, Widget? leading, VoidCallback? onTap, FCCInfoRowLayout layout = FCCInfoRowLayout.inline, Duration valueChangeDuration = const Duration(milliseconds: 220), Curve valueChangeCurve = Curves.easeOut, bool enableCopy = false, String? copyValue, String copyTooltip = 'Copy', VoidCallback? onCopied, bool expandable = false, bool initiallyExpanded = false, Widget? details, String? detailsText, Duration expandCollapseDuration = const Duration(milliseconds: 220), Curve expandCollapseCurve = Curves.easeInOut, List<
Widget> ? trailingBadges, List<String> ? trailingBadgeLabels, EdgeInsets margin = EdgeInsets.zero, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 5, vertical: 5), double horizontalGap = 8, double labelToValueGap = 8, double labelFlex = 2, double valueFlex = 3, bool dense = false, TextStyle? labelStyle, TextStyle? valueStyle, TextStyle? detailsTextStyle, bool inlineLabelValue = true, bool showLabel = true, FCCInfoRowShape shape = FCCInfoRowShape.none, bool use3DEffect = true, double borderRadius = 14, Color? backgroundColor, Color? borderColor, double elevation = 0}) -
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → double
-
final
- copyTooltip → String
-
final
- copyValue → String?
-
final
- dense → bool
-
final
- details → Widget?
-
final
- detailsText → String?
-
final
- detailsTextStyle → TextStyle?
-
final
- elevation → double
-
final
- enableCopy → bool
-
final
- expandable → bool
-
final
- expandCollapseCurve → Curve
-
final
- expandCollapseDuration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalGap → double
-
final
- initiallyExpanded → bool
-
final
- inlineLabelValue → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- labelFlex → double
-
final
- labelStyle → TextStyle?
-
final
- labelToValueGap → double
-
final
- layout → FCCInfoRowLayout
-
final
- leading → Widget?
-
final
- leadingIcon → IconData?
-
final
- margin → EdgeInsets
-
final
- onCopied → VoidCallback?
-
final
- onTap → VoidCallback?
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → FCCInfoRowShape
-
final
- showLabel → bool
-
final
-
trailingBadgeLabels
→ List<
String> ? -
final
-
trailingBadges
→ List<
Widget> ? -
final
- use3DEffect → bool
-
When true, and shape != FCCInfoRowShape.none, wraps in
FCCNeumorphicCard instead of a normal Container.
final
- value → String?
-
final
- valueChangeCurve → Curve
-
final
- valueChangeDuration → Duration
-
final
- valueFlex → double
-
final
- valueStyle → TextStyle?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FCCInfoRow> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited