FCCTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FCCTextField
Constructors
-
FCCTextField({Key? key, TextEditingController? controller, String? labelText, String? initialValue, IconData? prefixIcon, IconData? suffixIcon, VoidCallback? suffixIconCallback, Widget? suffixWidget, FormFieldValidator<
String> ? validator, bool readOnly = false, bool obscureText = false, Color? fillColor, double? fontSize, FontWeight? fontWeight, String? fontFamily, Color? textColor, TextStyle? style, TextAlign? textAlign, TextDirection? textDirection, VoidCallback? onTap, FocusNode? focusNode, TextInputType? keyboardType, ValueChanged<String> ? onChanged, String? helperText, String? hintText, int? maxLines, bool isDate = false, bool isTime = false, bool isDateTime = false, String dateFormat = 'yyyy-MM-dd', String timeFormat = 'HH:mm:ss', DateTime? defaultDate, DateTime? minDate, DateTime? maxDate, bool autoFocus = false, TextInputAction? textInputAction, List<TextInputFormatter> ? inputFormatters, int? maxLength, ValueChanged<String> ? onSubmitted, bool enabled = true, Color? cursorColor, double? cursorWidth = 2.0, VoidCallback? onEditingComplete, TextCapitalization textCapitalization = TextCapitalization.none, bool showClearButton = false, bool use3DEffect = true, bool isPill = false, String? semanticLabel, bool enableFocusEffect = true, bool required = false, String? requiredMessage, AutovalidateMode? autoValidateMode, bool showBorder = true, String? tooltip, bool visible = true}) -
const
Properties
- autoFocus → bool
-
final
- autoValidateMode → AutovalidateMode?
-
final
- controller → TextEditingController?
-
final
- cursorColor → Color?
-
final
- cursorWidth → double?
-
final
- dateFormat → String
-
final
- defaultDate → DateTime?
-
final
- enabled → bool
-
final
- enableFocusEffect → bool
-
final
- fillColor → Color?
-
final
- focusNode → FocusNode?
-
final
- fontFamily → String?
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- hintText → String?
-
final
- initialValue → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isDate → bool
-
final
- isDateTime → bool
-
final
- isPill → bool
-
final
- isTime → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- labelText → String?
-
final
- maxDate → DateTime?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minDate → DateTime?
-
final
- obscureText → bool
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onEditingComplete → VoidCallback?
-
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- onTap → VoidCallback?
-
final
- prefixIcon → IconData?
-
final
- readOnly → bool
-
final
- required → bool
-
final
- requiredMessage → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showBorder → bool
-
final
- showClearButton → bool
-
final
- style → TextStyle?
-
final
- suffixIcon → IconData?
-
final
- suffixIconCallback → VoidCallback?
-
final
- suffixWidget → Widget?
-
final
- textAlign → TextAlign?
-
final
- textCapitalization → TextCapitalization
-
final
- textColor → Color?
-
final
- textDirection → TextDirection?
-
final
- textInputAction → TextInputAction?
-
final
- timeFormat → String
-
final
- tooltip → String?
-
final
- use3DEffect → bool
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
- visible → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FCCTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited